@@ -7,3 +7,6 @@ delete_permission_allowed = Signal()
 update_permission_allowed = Signal()
 retrieve_permission_allowed = Signal()
 get_retrieve_id_obj = Signal()
+get_specfics_module = Signal()
+
+get_parent_obj = Signal()
\ No newline at end of file
